==> zio-aws-pinpoint_3-5.17.104.12-sources.jar: zio/aws/pinpoint/model/RemoveAttributesRequest.scala <==
package zio.aws.pinpoint.model
import zio.ZIO
import zio.aws.core.BuilderHelper
import zio.aws.pinpoint.model.primitives.__string
import scala.jdk.CollectionConverters.*
final case class RemoveAttributesRequest(
    applicationId: __string,
    attributeType: __string,
    updateAttributesRequest: zio.aws.pinpoint.model.UpdateAttributesRequest
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.pinpoint.model.RemoveAttributesRequest = {
    import RemoveAttributesRequest.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.pinpoint.model.RemoveAttributesRequest
      .builder()
      .applicationId(__string.unwrap(applicationId): java.lang.String)
      .attributeType(__string.unwrap(attributeType): java.lang.String)
      .updateAttributesRequest(updateAttributesRequest.buildAwsValue())
      .build()
  }
  def asReadOnly: zio.aws.pinpoint.model.RemoveAttributesRequest.ReadOnly =
    zio.aws.pinpoint.model.RemoveAttributesRequest.wrap(buildAwsValue())
}
object RemoveAttributesRequest {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.pinpoint.model.RemoveAttributesRequest
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.pinpoint.model.RemoveAttributesRequest =
      zio.aws.pinpoint.model.RemoveAttributesRequest(
        applicationId,
        attributeType,
        updateAttributesRequest.asEditable
      )
    def applicationId: __string
    def attributeType: __string
    def updateAttributesRequest
        : zio.aws.pinpoint.model.UpdateAttributesRequest.ReadOnly
    def getApplicationId: ZIO[Any, Nothing, __string] =
      ZIO.succeed(applicationId)
    def getAttributeType: ZIO[Any, Nothing, __string] =
      ZIO.succeed(attributeType)
    def getUpdateAttributesRequest: ZIO[
      Any,
      Nothing,
      zio.aws.pinpoint.model.UpdateAttributesRequest.ReadOnly
    ] = ZIO.succeed(updateAttributesRequest)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.pinpoint.model.RemoveAttributesRequest
  ) extends zio.aws.pinpoint.model.RemoveAttributesRequest.ReadOnly {
    override val applicationId: __string =
      zio.aws.pinpoint.model.primitives.__string(impl.applicationId())
    override val attributeType: __string =
      zio.aws.pinpoint.model.primitives.__string(impl.attributeType())
    override val updateAttributesRequest
        : zio.aws.pinpoint.model.UpdateAttributesRequest.ReadOnly =
      zio.aws.pinpoint.model.UpdateAttributesRequest
        .wrap(impl.updateAttributesRequest())
  }
  def wrap(
      impl: software.amazon.awssdk.services.pinpoint.model.RemoveAttributesRequest
  ): zio.aws.pinpoint.model.RemoveAttributesRequest.ReadOnly = new Wrapper(impl)
}

==> zio-aws-pinpoint_3-5.17.267.1-sources.jar: zio/aws/pinpoint/model/RemoveAttributesRequest.scala <==
package zio.aws.pinpoint.model
import zio.ZIO
import zio.aws.core.BuilderHelper
import zio.aws.pinpoint.model.primitives.__string
import scala.jdk.CollectionConverters.*
final case class RemoveAttributesRequest(
    applicationId: __string,
    attributeType: __string,
    updateAttributesRequest: zio.aws.pinpoint.model.UpdateAttributesRequest
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.pinpoint.model.RemoveAttributesRequest = {
    import RemoveAttributesRequest.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.pinpoint.model.RemoveAttributesRequest
      .builder()
      .applicationId(applicationId: java.lang.String)
      .attributeType(attributeType: java.lang.String)
      .updateAttributesRequest(updateAttributesRequest.buildAwsValue())
      .build()
  }
  def asReadOnly: zio.aws.pinpoint.model.RemoveAttributesRequest.ReadOnly =
    zio.aws.pinpoint.model.RemoveAttributesRequest.wrap(buildAwsValue())
}
object RemoveAttributesRequest {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.pinpoint.model.RemoveAttributesRequest
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.pinpoint.model.RemoveAttributesRequest =
      zio.aws.pinpoint.model.RemoveAttributesRequest(
        applicationId,
        attributeType,
        updateAttributesRequest.asEditable
      )
    def applicationId: __string
    def attributeType: __string
    def updateAttributesRequest
        : zio.aws.pinpoint.model.UpdateAttributesRequest.ReadOnly
    def getApplicationId: ZIO[Any, Nothing, __string] =
      ZIO.succeed(applicationId)
    def getAttributeType: ZIO[Any, Nothing, __string] =
      ZIO.succeed(attributeType)
    def getUpdateAttributesRequest: ZIO[
      Any,
      Nothing,
      zio.aws.pinpoint.model.UpdateAttributesRequest.ReadOnly
    ] = ZIO.succeed(updateAttributesRequest)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.pinpoint.model.RemoveAttributesRequest
  ) extends zio.aws.pinpoint.model.RemoveAttributesRequest.ReadOnly {
    override val applicationId: __string = impl.applicationId(): __string
    override val attributeType: __string = impl.attributeType(): __string
    override val updateAttributesRequest
        : zio.aws.pinpoint.model.UpdateAttributesRequest.ReadOnly =
      zio.aws.pinpoint.model.UpdateAttributesRequest
        .wrap(impl.updateAttributesRequest())
  }
  def wrap(
      impl: software.amazon.awssdk.services.pinpoint.model.RemoveAttributesRequest
  ): zio.aws.pinpoint.model.RemoveAttributesRequest.ReadOnly = new Wrapper(impl)
}
